@@ -25,7 +25,7 @@ from mqttk.widgets.scrolled_text import CustomScrolledText
 class LogTab(ttk.Frame):
     def __init__(self, master, *args, **kwargs):
         super().__init__(master=master, *args, **kwargs)
-
+        self.master = master
         self.log_output = CustomScrolledText(self, font="Courier 14", exportselection=False, state='disabled',
                                              background="white", foreground="black")
         self.log_output.pack(fill='both', expand=1, padx=3, pady=3)
@@ -34,3 +34,9 @@ class LogTab(ttk.Frame):
         self.log_output.configure(state="normal")
         self.log_output.insert(tk.END, message)
         self.log_output.configure(state="disabled")
+
+    def mark_as_read(self, *args, **kwargs):
+        self.master.tab(self, text="Log")
+
+    def notify(self):
+        self.master.tab(self, text="* Log *")
